@@ -25,7 +25,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'CFLAGS': '-fno-strict-aliasing -O2 -pipe -DNDEBUG -O2 -pipe  -fPIC',
  'CFLAGSFORSHARED': '-fPIC',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--with-cxx_main' '--with-system-expat' '--with-system-ffi' '--enable-shared' '--with-fpectl' '--with-threads' '--srcdir=/rest/obj/ports/Python-2.7.5/Python-2.7.5' '--enable-ipv6' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/'",
+ 'CONFIG_ARGS': "'--enable-shared' '--srcdir=/usr/obj/ports/Python-2.7.6/Python-2.7.6' '--with-fpectl' '--with-threads' '--enable-ipv6' '--with-cxx_main' '--with-system-expat' '--with-system-ffi' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/'",
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python2.7',
  'COREPYTHONPATH': ':plat-openbsd5:lib-tk:lib-old',
@@ -65,6 +65,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
+ 'HAVE_ALLOCA_H': 0,
  'HAVE_ALTZONE': 0,
  'HAVE_ASINH': 1,
  'HAVE_ASM_TYPES_H': 0,
@@ -78,7 +79,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_BROKEN_POLL': 0,
  'HAVE_BROKEN_POSIX_SEMAPHORES': 0,
  'HAVE_BROKEN_PTHREAD_SIGMASK': 0,
- 'HAVE_BROKEN_SEM_GETVALUE': 1,
+ 'HAVE_BROKEN_SEM_GETVALUE': 0,
  'HAVE_BROKEN_UNSETENV': 0,
  'HAVE_C99_BOOL': 1,
  'HAVE_CHFLAGS': 1,
@@ -216,6 +217,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_PROCESS_H': 0,
  'HAVE_PROTOTYPES': 1,
  'HAVE_PTH': 0,
+ 'HAVE_PTHREAD_ATFORK': 1,
  'HAVE_PTHREAD_DESTRUCTOR': 0,
  'HAVE_PTHREAD_H': 1,
  'HAVE_PTHREAD_INIT': 0,
@@ -347,7 +349,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HGBRANCH': '',
  'HGTAG': '',
  'HGVERSION': '',
- 'HOST_GNU_TYPE': 'sh-unknown-openbsd5.4',
+ 'HOST_GNU_TYPE': 'sh-unknown-openbsd5.5',
  'HURD_C_THREADS': 0,
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include /usr/local/include/python2.7 /usr/local/include/python2.7',
  'INCLUDEDIR': '/usr/local/include',
@@ -422,7 +424,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PLATMACDIRS': 'plat-mac plat-mac/Carbon plat-mac/lib-scriptpackages \\',
  'PLATMACPATH': ':plat-mac:plat-mac/lib-scriptpackages',
  'POBJS': '\\',
- 'POSIX_SEMAPHORES_NOT_ENABLED': 1,
+ 'POSIX_SEMAPHORES_NOT_ENABLED': 0,
  'PROFILE_TASK': './Tools/pybench/pybench.py -n 2 --with-gc --with-syscheck',
  'PSRCS': '\\',
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
@@ -449,7 +451,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'RANLIB': 'ranlib',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/rest/obj/ports/Python-2.7.5/Python-2.7.5:',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.6/Python-2.7.6:',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '',
@@ -471,7 +473,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SIZEOF_PTHREAD_T': 4,
  'SIZEOF_SHORT': 2,
  'SIZEOF_SIZE_T': 4,
- 'SIZEOF_TIME_T': 4,
+ 'SIZEOF_TIME_T': 8,
  'SIZEOF_UINTPTR_T': 4,
  'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
@@ -488,10 +490,12 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SYSLIBS': '-lm',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TANH_PRESERVES_ZERO_SIGN': 1,
+ 'TCLTK_INCLUDES': '',
+ 'TCLTK_LIBS': '',
  'TESTOPTS': '-l',
  'TESTPATH': '',
  'TESTPROG': './Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/rest/obj/ports/Python-2.7.5/Python-2.7.5: ./python -Wd -3 -E -tt',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.6/Python-2.7.6: ./python -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
  'TIME_WITH_SYS_TIME': 1,
@@ -515,11 +519,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/rest/obj/ports/Python-2.7.5/Python-2.7.5',
- 'abs_srcdir': '/rest/obj/ports/Python-2.7.5/Python-2.7.5',
- 'build': 'sh-unknown-openbsd5.4',
+ 'abs_builddir': '/usr/obj/ports/Python-2.7.6/Python-2.7.6',
+ 'abs_srcdir': '/usr/obj/ports/Python-2.7.6/Python-2.7.6',
+ 'build': 'sh-unknown-openbsd5.5',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
- 'host': 'sh-unknown-openbsd5.4',
+ 'host': 'sh-unknown-openbsd5.5',
  'prefix': '/usr/local',
  'srcdir': '.'}
